# nn_torch
[![PyPI](https://img.shields.io/pypi/v/nn_torch)](https://pypi.org/project/nn_torch)

neural networks implemented by pytorch

## Get Started

install from PYPI
```shell script
pip install nn_torch
```

install from source code
```shell script
cd nn_torch
pip install .
```